@@ -21,7 +21,7 @@ from keystone.common import dependency
 from keystone.common import validation
 import keystone.conf
 from keystone import exception
-from keystone.i18n import _, _LW
+from keystone.i18n import _
 from keystone.identity import schema
 
 
@@ -134,8 +134,7 @@ class User(controller.V2Controller):
                         # old tenant.  This could occur if roles aren't found
                         # or if the project is invalid or if there are no roles
                         # for the user on that project.
-                        msg = _LW('Unable to remove user %(user)s from '
-                                  '%(tenant)s.')
+                        msg = 'Unable to remove user %(user)s from %(tenant)s.'
                         LOG.warning(msg, {'user': user_id,
                                           'tenant': old_user_ref['tenantId']})
 
@@ -153,7 +152,7 @@ class User(controller.V2Controller):
                         # that the project is invalid or roles are some how
                         # incorrect.  This shouldn't prevent the return of the
                         # new ref.
-                        msg = _LW('Unable to add user %(user)s to %(tenant)s.')
+                        msg = 'Unable to add user %(user)s to %(tenant)s.'
                         LOG.warning(msg, {'user': user_id,
                                           'tenant': user_ref['tenantId']})
 
